@@ -1,21 +1,13 @@
 #!/bin/sh
-# /etc/init.d/bootopts.sh - SliTaz boot options from the cmdline.
+#
+# /etc/init.d/bootopts.sh : SliTaz boot options from the cmdline
 #
 # Earlier boot options are in rcS, ex: config= and modprobe=
 #
 . /etc/init.d/rc.functions
 
-# Update fstab for swapon/swapoff
-add_swap_in_fstab()
-{
-	grep -q "$1	" /etc/fstab || cat >> /etc/fstab <<EOT
-$1	swap	swap	default	0 0
-EOT
-}
-
 # Get first usb disk
-usb_device()
-{
+usb_device() {
 	cd /sys/block
 	for i in sd* sda ; do
 		grep -qs 1 $i/removable && break
@@ -23,40 +15,10 @@ usb_device()
 	echo $i
 }
 
-# Default user account without password (uid=1000). In live mode the option
-# user=name can be used, but user must be added before home= to have home dir.
-# This option is not handled by a loop and case like others and has no
-# effect on an installed system.
-if ! grep -q "100[0-9]:100[0-9]" /etc/passwd; then
-	if fgrep -q "user=" /proc/cmdline; then
-		USER=`cat /proc/cmdline | sed 's/.*user=\([^ ]*\).*/\1/'`
-		# Avoid usage of an existing system user or root.
-		if grep -q ^$USER /etc/passwd; then
-			USER=tux
-		fi
-	else
-		USER=tux
-	fi
-	echo -n "Configuring user and group: $USER..."
-	adduser -D -s /bin/sh -g "SliTaz User" -G users -h /home/$USER $USER
-	passwd -d $USER >/dev/null
-	status
-	# Audio and cdrom group.
-	addgroup $USER audio
-	addgroup $USER cdrom
-	addgroup $USER video
-	addgroup $USER tty
-	# Slim default user.
-	if [ -f /etc/slim.conf ]; then
-		sed -i s/"default_user .*"/"default_user        $USER"/\
-			/etc/slim.conf
-	fi
-fi
-
 # Parse /proc/cmdline for boot options.
-echo "Parsing kernel cmdline for SliTaz live options... "
+echo "Checking for SliTaz cmdline options..."
 
-for opt in `cat /proc/cmdline`
+for opt in $(cat /proc/cmdline)
 do
 	case $opt in
 		eject)
@@ -140,12 +102,6 @@ do
 				cp -a /home/boot/rootfs/* /
 			fi ;;
 		laptop)
-			# Laptop option to load related Kernel modules.
-			echo "Loading laptop modules: ac, battery, fan, yenta_socket..."
-			for mod in ac battery fan yenta_socket
-			do
-				modprobe $mod
-			done
 			# Enable Kernel Laptop mode.
 			echo "5" > /proc/sys/vm/laptop_mode ;;
 		mount)
@@ -195,19 +151,37 @@ do
 	esac
 done
 
+# Default user account without password (uid=1000). In live mode the option
+# user=name can be used, but user must be added before home= to have home dir.
+# This option is not handled by a loop and case like others and has no
+# effect on an installed system.
+if ! grep -q "100[0-9]:100[0-9]" /etc/passwd; then
+	if fgrep -q "user=" /proc/cmdline; then
+		USER=$(cat /proc/cmdline | sed 's/.*user=\([^ ]*\).*/\1/')
+		# Avoid usage of an existing system user or root.
+		if grep -q ^$USER /etc/passwd; then
+			USER=tux
+		fi
+	else
+		USER=tux
+	fi
+	echo -n "Configuring user and group: $USER..."
+	adduser -D -s /bin/sh -g "SliTaz User" -G users -h /home/$USER $USER
+	passwd -d $USER >/dev/null
+	status
+	# Audio and cdrom group.
+	addgroup $USER audio
+	addgroup $USER cdrom
+	addgroup $USER video
+	addgroup $USER tty
+	# Slim default user.
+	if [ -f /etc/slim.conf ]; then
+		sed -i s/"default_user .*"/"default_user        $USER"/\
+			/etc/slim.conf
+	fi
+fi
+
 # If no default WM fallback to Openbox (we never know).
 if [ ! -f /etc/X11/wm.default ]; then
 	echo "openbox" > /etc/X11/wm.default
 fi
-
-# Activate an eventual swap file or partition.
-if [ "`fdisk -l | grep swap`" ]; then
-	for SWAP_DEV in `fdisk -l | sed '/swap/!d;s/ .*//'`; do
-		echo "Swap memory detected on: $SWAP_DEV"
-		add_swap_in_fstab $SWAP_DEV
-	done
-fi
-if grep -q swap /etc/fstab; then
-	echo "Activating swap memory..."
-	swapon -a
-fi
