@@ -1,6 +1,7 @@
 #!/bin/sh
-# /etc/init.d/network.sh - Network initialization boot script.
-# Config file is: /etc/network.conf
+#
+# /etc/init.d/network.sh : Network initialization boot script
+# Configuration file     : /etc/network.conf
 #
 . /etc/init.d/rc.functions
 
@@ -12,7 +13,7 @@ fi
 
 boot() {
 	# Set hostname.
-	echo -n "Setting hostname..."
+	echo -n "Setting hostname to: $(cat /etc/hostname)"
 	/bin/hostname -F /etc/hostname
 	status
 
@@ -21,6 +22,8 @@ boot() {
 	/sbin/ifconfig lo 127.0.0.1 up
 	/sbin/route add 127.0.0.1 lo
 	status
+
+	[ -s /etc/sysctl.conf ] && sysctl -p /etc/sysctl.conf
 }
 
 # Use ethernet
@@ -30,7 +33,7 @@ eth() {
 
 # For wifi. Users just have to enable it through yes and usually
 # essid any will work and the interface is autodetected.
-wifi() {	
+wifi() {
 	if [ "$WIFI" = "yes" ] || fgrep -q "wifi" /proc/cmdline; then
 		ifconfig $INTERFACE down
 
@@ -52,11 +55,12 @@ wifi() {
 			iwconfig $WIFI_INTERFACE txpower on
 		fi
 		status
-		
+
 		[ -n "$WPA_DRIVER" ] || WPA_DRIVER="wext"
 		IWCONFIG_ARGS=""
 		[ -n "$WIFI_MODE" ] && IWCONFIG_ARGS="$IWCONFIG_ARGS mode $WIFI_MODE"
 		[ -n "$WIFI_CHANNEL" ] && IWCONFIG_ARGS="$IWCONFIG_ARGS channel $WIFI_CHANNEL"
+		[ -n "$WIFI_AP" ] && IWCONFIG_ARGS="$IWCONFIG_ARGS ap $WIFI_AP"
 		# unencrypted network
 		if [ "$WIFI_KEY" == "" -o "$WIFI_KEY_TYPE" == "none" ]; then
 			iwconfig $WIFI_INTERFACE essid "$WIFI_ESSID" $IWCONFIG_ARGS
@@ -159,8 +163,22 @@ dhcp() {
 static_ip() {
 	if [ "$STATIC" = "yes" ] ; then
 		echo "Configuring static IP on $INTERFACE: $IP..."
-		/sbin/ifconfig $INTERFACE $IP netmask $NETMASK up
-		/sbin/route add default gateway $GATEWAY
+		if [ ! -z $BROADCAST ]; then
+			/sbin/ifconfig $INTERFACE $IP netmask $NETMASK broadcast $BROADCAST up
+		else
+			/sbin/ifconfig $INTERFACE $IP netmask $NETMASK up
+		fi
+		
+		# Use ip to set gateways if iproute.conf exist
+		if [ -f /etc/iproute.conf ]; then
+		    while read line
+			do
+				ip route add $line
+			done < /etc/iproute.conf
+		else
+			/sbin/route add default gateway $GATEWAY
+		fi
+		
 		# wpa_supplicant waits for wpa_cli
 		[ -d /var/run/wpa_supplicant ] && wpa_cli -B
 		# Multi-DNS server in $DNS_SERVER.
@@ -169,6 +187,9 @@ static_ip() {
 		do
 			echo "nameserver $NS" >> /etc/resolv.conf
 		done
+		if [ ! -z $DOMAIN ];then
+		    echo "search $DOMAIN" >> /etc/resolv.conf
+		fi
 		for HELPER in /etc/ipup.d/*; do
 			[ -x $HELPER ] && $HELPER $INTERFACE $DNS_SERVER
 		done
